<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pt_BR">
<context>
    <name>ClipboardItem</name>
    <message>
        <location filename="../dock-clipboard-plugin/clipboarditem.cpp" line="33"/>
        <source>Clipboard</source>
        <translation>Área de transferência</translation>
    </message>
    <message>
        <location filename="../dock-clipboard-plugin/clipboarditem.cpp" line="64"/>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
</context>
<context>
    <name>ClipboardPlugin</name>
    <message>
        <location filename="../dock-clipboard-plugin/clipboardplugin.cpp" line="44"/>
        <source>Clipboard</source>
        <translation>Área de transferência</translation>
    </message>
</context>
<context>
    <name>ItemData</name>
    <message>
        <location filename="../dde-clipboard/itemdata.cpp" line="130"/>
        <source>Picture</source>
        <translation>Imagem</translation>
    </message>
    <message>
        <location filename="../dde-clipboard/itemdata.cpp" line="132"/>
        <source>Text</source>
        <translation>Texto</translation>
    </message>
    <message>
        <location filename="../dde-clipboard/itemdata.cpp" line="134"/>
        <source>File</source>
        <translation>Arquivo</translation>
    </message>
    <message>
        <location filename="../dde-clipboard/itemdata.cpp" line="146"/>
        <source>%1 characters</source>
        <translation>%1 caracteres</translation>
    </message>
</context>
<context>
    <name>ItemWidget</name>
    <message>
        <location filename="../dde-clipboard/itemwidget.cpp" line="369"/>
        <source>%1 files (%2...)</source>
        <translation>%1 arquivos (%2...)</translation>
    </message>
    <message>
        <location filename="../dde-clipboard/itemwidget.cpp" line="420"/>
        <location filename="../dde-clipboard/itemwidget.cpp" line="609"/>
        <source>(File deleted)</source>
        <translation>(Arquivo excluído)</translation>
    </message>
    <message>
        <location filename="../dde-clipboard/itemwidget.cpp" line="443"/>
        <source>Yesterday</source>
        <translation>Ontem</translation>
    </message>
    <message>
        <location filename="../dde-clipboard/itemwidget.cpp" line="449"/>
        <source>Just now</source>
        <translation>Agora mesmo</translation>
    </message>
    <message>
        <location filename="../dde-clipboard/itemwidget.cpp" line="451"/>
        <source>1 minute ago</source>
        <translation>1 minuto atrás</translation>
    </message>
    <message>
        <location filename="../dde-clipboard/itemwidget.cpp" line="453"/>
        <source>%1 minutes ago</source>
        <translation>%1 minutos atrás</translation>
    </message>
    <message>
        <location filename="../dde-clipboard/itemwidget.cpp" line="455"/>
        <source>1 hour ago</source>
        <translation>1 hora atrás</translation>
    </message>
    <message>
        <location filename="../dde-clipboard/itemwidget.cpp" line="457"/>
        <source>%1 hours ago</source>
        <translation>%1 horas atrás</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../dde-clipboard/mainwindow.cpp" line="301"/>
        <source>Clipboard</source>
        <translation>Área de transferência</translation>
    </message>
    <message>
        <location filename="../dde-clipboard/mainwindow.cpp" line="304"/>
        <source>Clear all</source>
        <translation>Limpar tudo</translation>
    </message>
    <message>
        <location filename="../dde-clipboard/mainwindow.cpp" line="329"/>
        <source>Copy the content to clipboard</source>
        <translation>Copiar conteúdo para área de transferência</translation>
    </message>
</context>
</TS>